==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/RankedEmailAddress.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "address", 
    "rank"})
@JsonInclude(Include.NON_NULL)
public class RankedEmailAddress implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("address")
    protected String address;

    @JsonProperty("rank")
    protected Double rank;

    protected RankedEmailAddress() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.rankedEmailAddress";
    }

    @Property(name="address")
    @JsonIgnore
    public Optional<String> getAddress() {
        return Optional.ofNullable(address);
    }

    public RankedEmailAddress withAddress(String address) {
        RankedEmailAddress _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.rankedEmailAddress");
        _x.address = address;
        return _x;
    }

    @Property(name="rank")
    @JsonIgnore
    public Optional<Double> getRank() {
        return Optional.ofNullable(rank);
    }

    public RankedEmailAddress withRank(Double rank) {
        RankedEmailAddress _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.rankedEmailAddress");
        _x.rank = rank;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String address;
        private Double rank;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder address(String address) {
            this.address = address;
            this.changedFields = changedFields.add("address");
            return this;
        }

        public Builder rank(Double rank) {
            this.rank = rank;
            this.changedFields = changedFields.add("rank");
            return this;
        }

        public RankedEmailAddress build() {
            RankedEmailAddress _x = new RankedEmailAddress();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.rankedEmailAddress";
            _x.address = address;
            _x.rank = rank;
            return _x;
        }
    }

    private RankedEmailAddress _copy() {
        RankedEmailAddress _x = new RankedEmailAddress();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.address = address;
        _x.rank = rank;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RankedEmailAddress[");
        b.append("address=");
        b.append(this.address);
        b.append(", ");
        b.append("rank=");
        b.append(this.rank);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/RankedEmailAddress.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Double;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "address", 
    "rank"})
@JsonInclude(Include.NON_NULL)
public class RankedEmailAddress implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("address")
    protected String address;

    @JsonProperty("rank")
    protected Double rank;

    protected RankedEmailAddress() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.rankedEmailAddress";
    }

    @Property(name="address")
    @JsonIgnore
    public Optional<String> getAddress() {
        return Optional.ofNullable(address);
    }

    public RankedEmailAddress withAddress(String address) {
        RankedEmailAddress _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.rankedEmailAddress");
        _x.address = address;
        return _x;
    }

    @Property(name="rank")
    @JsonIgnore
    public Optional<Double> getRank() {
        return Optional.ofNullable(rank);
    }

    public RankedEmailAddress withRank(Double rank) {
        RankedEmailAddress _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.rankedEmailAddress");
        _x.rank = rank;
        return _x;
    }

    public RankedEmailAddress withUnmappedField(String name, Object value) {
        RankedEmailAddress _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String address;
        private Double rank;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder address(String address) {
            this.address = address;
            this.changedFields = changedFields.add("address");
            return this;
        }

        public Builder rank(Double rank) {
            this.rank = rank;
            this.changedFields = changedFields.add("rank");
            return this;
        }

        public RankedEmailAddress build() {
            RankedEmailAddress _x = new RankedEmailAddress();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.rankedEmailAddress";
            _x.address = address;
            _x.rank = rank;
            return _x;
        }
    }

    private RankedEmailAddress _copy() {
        RankedEmailAddress _x = new RankedEmailAddress();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.address = address;
        _x.rank = rank;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RankedEmailAddress[");
        b.append("address=");
        b.append(this.address);
        b.append(", ");
        b.append("rank=");
        b.append(this.rank);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
